@@ -6,7 +6,7 @@ import ajax_validation
 
 register = template.Library()
 
-VALIDATION_SCRIPT = open(os.path.join(os.path.dirname(ajax_validation.__file__), 'static', 'js', 'jquery-ajax-validation.js')).read()
+VALIDATION_SCRIPT = open(os.path.join(os.path.dirname(ajax_validation.__file__), 'media', 'ajax_validation', 'js', 'jquery-ajax-validation.js')).read()
 
 def include_validation():
     return '''<script type="text/javascript">%s</script>''' % VALIDATION_SCRIPT
